get_ids_registering_eligible_new_completions_via_suotar

Function get_ids_registering_eligible_new_completions_via_suotar 

pub async fn get_ids_registering_eligible_new_completions_via_suotar(
    conn: &mut PgConnection,
    course_ids: &[Uuid],
) -> ModelResult<Vec<Uuid>>
Ids of the courses’ modules whose new completions go through credit registration via Suotar when the student holds a linked student number.