pub fn validate_completion_registration_link(
link: Option<&str>,
) -> ModelResult<()>Expand description
Errors with InvalidRequest unless link is empty or an absolute https:// URL. Students get
the link as an href, so no other scheme may be stored.