pub struct CourseModuleSuotarRealisationEdit {
pub course_unit_realisation_id: String,
pub label: Option<String>,
pub active: bool,
}Fields
course_unit_realisation_id: Stringlabel: Option<String>Rendered to students as the name of the realisation their credits go against.
active: boolTrait Implementations
Sourceimpl Clone for CourseModuleSuotarRealisationEdit
impl Clone for CourseModuleSuotarRealisationEdit
Sourcefn clone(&self) -> CourseModuleSuotarRealisationEdit
fn clone(&self) -> CourseModuleSuotarRealisationEdit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CourseModuleSuotarRealisationEdit
impl ComposeSchema for CourseModuleSuotarRealisationEdit
Sourceimpl<'de> Deserialize<'de> for CourseModuleSuotarRealisationEdit
impl<'de> Deserialize<'de> for CourseModuleSuotarRealisationEdit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CourseModuleSuotarRealisationEdit
impl PartialEq for CourseModuleSuotarRealisationEdit
Sourcefn eq(&self, other: &CourseModuleSuotarRealisationEdit) -> bool
fn eq(&self, other: &CourseModuleSuotarRealisationEdit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CourseModuleSuotarRealisationEdit
impl ToSchema for CourseModuleSuotarRealisationEdit
impl StructuralPartialEq for CourseModuleSuotarRealisationEdit